summaryrefslogtreecommitdiff
path: root/sw/inc/IGrammarContact.hxx
diff options
context:
space:
mode:
authorChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2015-05-20 13:05:49 +0200
committerChristian Lohmaier <lohmaier+LibreOffice@googlemail.com>2015-05-20 13:05:49 +0200
commitab465b90f6c6da5595393a0ba73f33a1e71a2b65 (patch)
tree36b77192de2799a11b4bf0b269cb3f74d0a0bb1f /sw/inc/IGrammarContact.hxx
parent0db96caf0fcce09b87621c11b584a6d81cc7df86 (diff)
bin/rename-sw-abbreviations.sh libreoffice-5-0-branch-point
renames the most annoying abbreviations in Writer (and partially in the shared code too). Change-Id: I9a62759138126c1537cc5c985ba05cf54d6132d9
Diffstat (limited to 'sw/inc/IGrammarContact.hxx')
-rw-r--r--sw/inc/IGrammarContact.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sw/inc/IGrammarContact.hxx b/sw/inc/IGrammarContact.hxx
index 62c053f90fcb..58dc2ebb1ef5 100644
--- a/sw/inc/IGrammarContact.hxx
+++ b/sw/inc/IGrammarContact.hxx
@@ -21,11 +21,11 @@
#define INCLUDED_SW_INC_IGRAMMARCONTACT_HXX
struct SwPosition;
-class SwTxtNode;
+class SwTextNode;
class SwGrammarMarkUp;
class SwDoc;
/** Organizer of the contact between SwTxtNodes and grammar checker
*/
class IGrammarContact
{
@@ -42,9 +42,9 @@ public:
/** getGrammarCheck checks if the given text node is blocked by the current cursor
if not, the normal markup list is returned
if blocked, it will return a markup list "proxy"
- @returns a markup list (grammar) for the given SwTxtNode
+ @returns a markup list (grammar) for the given SwTextNode
*/
- virtual SwGrammarMarkUp* getGrammarCheck( SwTxtNode& rTxtNode, bool bCreate ) = 0;
+ virtual SwGrammarMarkUp* getGrammarCheck( SwTextNode& rTextNode, bool bCreate ) = 0;
/** finishGrammarCheck() has to be called if a grammar checking has been completed
for a text node. If this text node has not been hided by the current proxy list
@@ -52,7 +52,7 @@ public:
repaint will be triggered by a timer
@returns void
*/
- virtual void finishGrammarCheck( SwTxtNode& rTxtNode ) = 0;
+ virtual void finishGrammarCheck( SwTextNode& rTextNode ) = 0;
public:
virtual ~IGrammarContact() {}
@@ -68,12 +68,12 @@ IGrammarContact* createGrammarContact();
/** getGrammarContact() delivers the grammar contact of the document (for a given textnode)
@returns grammar contact
*/
-IGrammarContact* getGrammarContact( const SwTxtNode& );
+IGrammarContact* getGrammarContact( const SwTextNode& );
/** finishGrammarCheck() calls the same function of the grammar contact of the document (for a given textnode)
@returns void
*/
-void finishGrammarCheck( SwTxtNode& );
+void finishGrammarCheck( SwTextNode& );
#endif // INCLUDED_SW_INC_IGRAMMARCONTACT_HXX
@@ -21,11 +21,11 @@
class SwGrammarMarkUp;
class SwDoc;
-/** Organizer of the contact between SwTxtNodes and grammar checker
+/** Organizer of the contact between SwTextNodes and grammar checker
*/
class IGrammarContact